# Welcome to FretBoardGtr Documentation

Package that make easy creation of **highly customizable** fretboards and chords diagrams

## Table of content

```{toctree}
:maxdepth: 2
:caption: Guides

get-started/index.md
```

```{toctree}
:maxdepth: 2
:caption: References

api_documentation/index.md
```
